import {Component, OnInit} from '@angular/core';
import {MenuItem, RootMenuItem} from './openaireLibrary/sharedComponents/menu';
import {EnvProperties} from './openaireLibrary/utils/properties/env-properties';
import {User} from './openaireLibrary/login/utils/helper.class';
import {properties} from '../environments/environment';
import {LayoutService} from './services/layout.service';
import {Header} from './openaireLibrary/sharedComponents/navigationBar.component';

@Component({
  selector: 'app',
  templateUrl: './app.component.html',
})

export class AppComponent implements OnInit {
  title = 'OpenAIRE - Research Graph';
  userMenuItems: MenuItem[] = [];
  menuItems: RootMenuItem [] = [];
  logInUrl = null;
  logOutUrl = null;
  properties: EnvProperties = properties;
  showMenu: boolean = false;
  user: User;
  header: Header;
  logoPath: string = 'assets/common-assets/';
  
  constructor(private layoutService: LayoutService) {}
  
  ngOnInit() {
    this.logInUrl = this.properties.loginUrl;
    this.logOutUrl = this.properties.logoutUrl;
    this.showMenu = true;
    this.header = {
      route: "/",
      url: null,
      title: 'graph',
      logoUrl: this.logoPath + 'logo-large-graph.png',
      logoSmallUrl:this.logoPath + 'logo-small-graph.png',
      position:'left',
      badge:true
    };
    this.layoutService.isHome.subscribe(isHome => {
      this.buildMenu(isHome);
    });
  }
  
  buildMenu(isHome) {
    this.menuItems = [
      {
        rootItem: new MenuItem("about", "About", "", "/about", false, [], null, {}),
        items: [
          new MenuItem("overview", "Overview", "", "/about", false, [], null, {}),
          new MenuItem("architecture", "Architecture", "", "/about", false, [], null, {}, null, 'architecture'),
          new MenuItem("metrics", "Data and Metrics", "", "/about", false, [], null, {}, null, 'metrics'),
          new MenuItem("infrastructure", "Infrastructure", "", "/about", false, [], null, {}, null, 'infrastructure'),
          new MenuItem("team", "Team", "", "/about", false, [], null, {}, null, 'team')
        ]
      },
      {
        rootItem: new MenuItem("resources", "Resources", "", "/resources", false, [], null, {}),
        items: [
          new MenuItem("api", "API", "", "/resources", false, [], null, {}),
          new MenuItem("schema", "Metadata Schema", "", "/resources", false, [], null, {}, null, "schema"),
          // new MenuItem("sources", "Sources", "", "/resources", false, [], null, {}, null, "sources"),
        ]
      },
      {
        rootItem: new MenuItem("contact", "Support", "", "/support", false, [], null, {}),
        items: [
          // new MenuItem("contact", "Contact", "", "/support", false, [], null, {}),
          // new MenuItem("documentation", "Documentation", "", "/support", false, [], null, {}, null, "documentation"),
          // new MenuItem("faq", "FAQs", "", "/support", false, [], null, {}, null, "faq"),
        ]
      }
    ];
    if(!isHome) {
      this.menuItems = [{
        rootItem: new MenuItem("home", "Home", "", "/", false, [], null, {}),
        items: []
      }].concat(this.menuItems);
    }
  }
}
